
## 0.1.3 (2025-04-10)



- bugfix: adding example scenarios to distributed wheels
## 0.1.3 (2025-04-09)
- feature: Adding more information to tournament results
- bugfix: tournaments run with more competitors than edges
- docs: Correcting links to ANL2025Negotiator in tutorials
